CustomResponseEntity class
Constructors
- CustomResponseEntity({required int statusCode, ErrorResult errorMessage(dynamic exception)?, dynamic callBackEvent()?})
Properties
- callBackEvent → dynamic Function()?
-
final
- errorMessage → ErrorResult Function(dynamic exception)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited