RestApiClient class

Constructors

RestApiClient(Dio _dio, CustomErrorHandler _customErrorHandler, NetworkInfoImpl _networkInfoImpl)

Properties

dio Dio
no setter
getConfiguration RestApiConfiguration
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request({required String path, required RequestData data, required RequestMethod requestMethod, Map<String, dynamic>? headers, CancelToken? cancelToken, Options? options}) Future<ResponseEntity<Map<String, dynamic>?>>
setConfiguration(RestApiConfiguration restApiConfiguration) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited